@@ -4,16 +4,18 @@ from .google_trans import GoogleTranslator
 from .pons import PonsTranslator
 from .linguee import LingueeTranslator
 from .mymemory import MyMemoryTranslator
+from .yandex import YandexTranslator
 from .detection import single_detection, batch_detection
 
 
 __author__ = """Nidhal Baccouri"""
 __email__ = 'nidhalbacc@gmail.com'
-__version__ = '1.2.0'
+__version__ = '1.2.1'
 
 __all__ = [GoogleTranslator,
            PonsTranslator,
            LingueeTranslator,
            MyMemoryTranslator,
+           YandexTranslator,
            single_detection,
            batch_detection]
